@@ -1,8 +1,9 @@
 import logging
 import sys
+import numpy
 
 import map_analyser.mapanalyser as ma
-from map_analyser.app.presenters import Viewer
+from map_analyser.app.presenters import Viewer, TestViewer
 from map_analyser.app.util import read_config
 from map_analyser.maplib import load_map
 
@@ -16,6 +17,11 @@ root = logging.getLogger()
 root.setLevel(logging.DEBUG)
 root.addHandler(handler)
 
+if DEBUG:
+    numpy.seterr("raise")
+else:
+    numpy.seterr("ignore")
+
 
 def main(viewer, params):
     """This is the flow of a program."""
@@ -34,10 +40,12 @@ def main(viewer, params):
     areas = ma.map_to_areas(map, speeds)
     areas = ma.filter_areas(areas)
 
+    yield 'Offsetting polygons'
+    areas = ma.offset_areas(areas)
+
     yield 'Cleaning polygons'
-    areas = ma.clean_areas(areas)
-    tmp = ma.offset_areas(areas)
-    areas = ma.create_default_area(areas)
+    tmp = ma.clean_areas(areas)
+    areas = ma.create_default_area(areas) if params["default_area"] else []
     areas.extend(tmp)
 
     used_speeds = set()
@@ -76,20 +84,21 @@ def main(viewer, params):
                                 end,
                                 max_speed=max(used_speeds),  # max speed is at most 100 (percent)
                                 in_parallel=params["in_parallel"])
-    viewer.add_path(path)
+    viewer.add_path(path, color="#FF0000")
 
     yield 'Calculation finnished'
 
 
 def run():
     params = {
-        "in_parallel": False,
+        "in_parallel": True,
         "neighbours_by_point": False,
+        "default_area": False,
         "config_name": 'configISOM2017.csv',
         "input": None
     }
 
-    vw = Viewer()
+    vw = Viewer() if not DEBUG else TestViewer()
     vw.entry(lambda viewer: main(viewer, params))
 
 
