@@ -70,6 +70,7 @@ class Viewer:
     def get_start_and_end(self):
         start, end = self._start_and_end[:2]
         start, end = ml.Coord(*start), ml.Coord(*end)
+        logging.info(str(start)+str(end))
         return start, end
 
     @staticmethod
@@ -161,13 +162,12 @@ class TestViewer(Viewer):
 
     def add_graph(self, graph):
         self.start, self.end = graph.areas[0].get_center(), graph.areas[-1].get_center()
-        self.start, self.end = ml.Coord(3113, 6470), ml.Coord(706, -8650)
-        print(self.start, self.end)
         super().add_graph(graph)
 
     def get_start_and_end(self):
         self.add_control(self.start)
         self.add_control(self.end)
+        logging.info(str(self.start)+str(self.end))
         return self.start, self.end
 
     def prompt_start_end(self, bind=True):
