@@ -366,8 +366,8 @@ def polygonSlice(polygon, cutEdges):
 
         # Was given one edge
         cutEdge = cutEdges
-        i = polygon._index(cutEdge[0])
-        j = polygon._index(cutEdge[1])
+        i = polygon.index(cutEdge[0])
+        j = polygon.index(cutEdge[1])
 
         if i != -1 and j != -1:
             return [polygonCopy(polygon, i, j),
