@@ -911,7 +911,7 @@ class Polygon(object):
             pass
 
         g = G()
-        g.del_index = 0
+        g.delindex = 0
 
         def check_decomp(l, p_minus_l, p):
             """check the decomposition l of polygon p"""
@@ -1001,7 +1001,7 @@ class Polygon(object):
             holes.remove(closest_hole)
             if Polygon.is_clockwise_s(closest_hole): closest_hole = closest_hole.clone_ccw()
 
-            i = closest_hole.points._index(d_a)
+            i = closest_hole.points.index(d_a)
             j = p.index(d_b)
 
             extension = [d_b] + closest_hole.points[i:] + closest_hole.points[:i + 1]
@@ -1068,8 +1068,8 @@ class Polygon(object):
 
             out.append(Polygon.from_pointlist([p[k] for k in l]))
             for v in sorted(l[1:-1], reverse=True):
-                dbg(p[v], (255, 0, 255), "del %d" % g.del_index)
-                g.del_index += 1
+                dbg(p[v], (255, 0, 255), "del %d" % g.delindex)
+                g.delindex += 1
                 del p[v]
 
             return True
@@ -1170,7 +1170,7 @@ class Polygon(object):
         # filter intersection points that are boundary points
         for int_point in set(filter(lambda x: x in pts, intersections)):
 
-            i = pts._index(int_point)
+            i = pts.index(int_point)
             prv = pts[i - 1]
             nxt = pts[(i + 1) % len(pts)]
 
