@@ -12,7 +12,6 @@ def get_point(a, b, x):
 
 
 def loss_function(x, common_edges, start, end, speeds):
-    # TODO write faster code
     points = [get_point(a, b, x) for (a, b), x in zip(common_edges, x)]
     dist = speeds[0] * (np.sqrt((start[0] - points[0][0]) ** 2 + (start[1] - points[0][1]) ** 2))
 
@@ -102,55 +101,3 @@ def solve_all(start, end, speeds, common_edges):
             # print(ex)
 
     return problem.value, lamb.value
-
-
-"""
-
-minimize(fun, x0[, args, method, jac, hess, …])
-Minimization of scalar function of one or more variables.
-The minimize function supports the following methods:
-
-'Nelder-Mead','Powell','CG','BFGS','Newton-CG','L-BFGS-B','TNC','COBYLA','SLSQP','trust-constr','dogleg','trust-ncg','trust-krylov','trust-exact',"""
-# Bounds on variables for L-BFGS-B, TNC, SLSQP, Powell, and trust-constr methods.
-
-# Constraints definition (only for COBYLA, SLSQP and trust-constr).
-
-# https://cvxopt.org/
-
-# TODO
-# try CVXPY https://www.cvxpy.org/tutorial/advanced/index.html#advanced
-
-# or implement gradient descent algorithm (derivative is known -> calculate)
-# L2 norm is not defferentiable at 0!!! If you're trying to do gradient descent with these formulations, the only one that will really work is the squared L2 norm, because that's the only one that's differentiable everywhere.
-
-# geometric means
-"""
-import cvxpy as cp
-import numpy as np
-import matplotlib.pyplot as plt
-
-#Generate random test data
-POINT_NUM = 100
-pts       = np.random.rand(POINT_NUM,2)
-
-c_pt      = cp.Variable(2)           #The center point we wish to locate
-distances = cp.Variable(POINT_NUM)   #Distance from the center point to each data point
-
-#Generate constraints. These are used to hold distances.
-constraints = []                     
-for i in range(POINT_NUM):
-    constraints.append( cp.norm(c_pt-pts[i,:])<=distances[i] ) 
-
-objective = cp.Minimize(cp.sum(distances))
-
-problem = cp.Problem(objective,constraints)
-
-optimal_value = problem.solve()
-
-print("Optimal value = {0}".format(optimal_value))
-print("Optimal location = {0}".format(c_pt.value))
-
-plt.scatter(x=pts[:,0], y=pts[:,1], s=1)
-plt.scatter(c_pt.value[0], c_pt.value[1], s=10)
-plt.show()
-"""
