@@ -12,13 +12,17 @@ from .util import average, distance, rect_point_distance
 def find_good_path(graph, start, end, max_speed=100):
     dist, path = CentersAStar(graph, start, end).find_first_solution(max_speed)
 
+    logging.info(dist)
+
     return path
 
 
 def find_fastest_path(graph, start, end, max_speed=100, in_parallel=False):
     dist, path = CentersAStar(graph, start, end).find_first_solution(max_speed)
 
-    path = Pruning(graph, start, end, max_speed, dist).find_best_path(in_parallel=in_parallel)
+    dist, path = Pruning(graph, start, end, max_speed, dist).find_best_path(in_parallel=in_parallel)
+
+    logging.info(dist)
 
     return path
 
@@ -26,7 +30,7 @@ def find_fastest_path(graph, start, end, max_speed=100, in_parallel=False):
 def solve_optimization(graph, areas, return_path=False):
     n = len(areas) - 1
 
-    if n == 0:  # start and end are in same area
+    if n <= 0:  # start and end are in same area
         common_edges, lambdas = [], []
         dist = 1 / areas[0].speed * distance(graph.start, graph.end)
     else:
@@ -35,13 +39,13 @@ def solve_optimization(graph, areas, return_path=False):
         dist, lambdas = solve(graph.start, graph.end, speeds, common_edges)
 
     if return_path:
-        path = [graph.start] + [get_point(*e, l) for e, l in zip(common_edges, lambdas)] + [graph.end]
+        path = [tuple(graph.start)] + [get_point(*e, l) for e, l in zip(common_edges, lambdas)] + [tuple(graph.end)]
         return dist, path
     else:
         return dist
 
 
-class CentersAStar():
+class CentersAStar:
     def __init__(self, graph, start, end):
         graph.set_start_end(start, end)
         self.graph = graph
@@ -115,7 +119,7 @@ class BrutForce:
 
     def find_best_path(self, initial=float('inf'), in_parallel=False):
         best = initial
-        best_path = []
+        best_path = [self.graph.start, self.graph.start]
 
         if in_parallel:
             with concurrent.futures.ThreadPoolExecutor() as executor:
@@ -132,37 +136,35 @@ class BrutForce:
 
                 for chunk in to_chunks(6 * cpu_count(), self.iterate_paths_recursive(self.graph)):
                     for value, path in executor.map(solve_lamb, chunk):
-                        if value < best:
+                        if value < best + 0.01:
                             logging.debug(f'>>>>>> better value: {value}')
                             best = value
                             best_path = path
 
         else:
             for path in self.iterate_paths_recursive(self.graph):
-                value = solve_optimization(self.graph, path)
-                if value <= best:
+                value, path = solve_optimization(self.graph, path, return_path=True)
+                print(value)
+                if value <= best + 0.01:
                     logging.debug(f'>>>>>> better value: {value}')
                     best = value
                     best_path = path
 
-        dist, path = solve_optimization(self.graph, best_path, return_path=True)
-
-        return dist, path
+        return best, best_path
 
 
 class Pruning(BrutForce):
     def __init__(self, graph, start, end, max_speed, dist):
+        super().__init__(graph, start, end)
         self.max_speed = max_speed
         self.dist = dist
-        graph.set_start_end(start, end)
-        self.graph = graph
 
     def find_best_path(self, initial=None, in_parallel=False):
         self.prune(self.dist, self.max_speed)
 
         dist, path = super().find_best_path(initial=self.dist, in_parallel=in_parallel)
 
-        return path
+        return dist, path
 
     def prune(self, dist, max_speed):
         self.max_speed = max_speed
@@ -176,6 +178,8 @@ class Pruning(BrutForce):
             if 1 / max_speed * (d1 + d2) >= dist:
                 unwanted.append(area)
 
+        logging.info(f"Prunning {len(unwanted)} areas ({len(self.graph.areas) - len(unwanted)} left).")
+
         for area in unwanted:
             for a in area.neighbours:
                 a.neighbours.remove(area)
