@@ -89,8 +89,7 @@ def map_to_areas(map, speeds):
 
         code = symbol.code.split('.')[0] if '.' in symbol.code else symbol.code
         if code in speeds:
-            if speeds[code] >= 0:
-                all_objects.append(Area(o, symbol, colors=map.colors, speed=speeds[code]))
+            all_objects.append(Area(o, symbol, colors=map.colors, speed=speeds[code]))
         # else:
         #     logging.warning(f"Code {code} not in config.")
 
@@ -109,7 +108,7 @@ def filter_areas(areas):
             a.symbol_type in (ml.Symbol.LINE_SYMBOL, ml.Symbol.AREA_SYMBOL, ml.Symbol.COMBINED_SYMBOL)]
 
 
-class Area():
+class Area:
     HOLES_ORIENTATION = False
     ORIENTATION = True
 
@@ -181,6 +180,9 @@ class Area():
     def __repr__(self):
         return self.__str__()
 
+    def __hash__(self):
+        return hash(self.get_center())
+
     def orientation(self):
         return orientation(self.coords_zipped)
 
@@ -211,7 +213,7 @@ class Area():
 
     def get_center(self):
         if not hasattr(self, '_center'):
-            self._center = ml.Coord(self.coords.x.mean(), self.coords.y.mean())
+            self._center = ml.Coord(int(round(self.coords.x.mean())), int(round(self.coords.y.mean())))
         return self._center
 
     def add_hole(self, hole, orient=None):
