@@ -38,13 +38,17 @@ def _triangulate1(area):
 
 
 def _decomp4(area):
-    try:
-        ret = func_timeout(10, Polygon.convex_decompose, args=(Polygon.from_tuples(area.coords_zipped),
-                                                               [Polygon.from_tuples(hole) for hole in area.holes]))
+    # implementation with timeout:
+    # try:
+    #     ret = func_timeout(1000, Polygon.convex_decompose, args=(Polygon.from_tuples(area.coords_zipped),
+    #                                                            [Polygon.from_tuples(hole) for hole in area.holes]))
+    #
+    # except FunctionTimedOut:
+    #     logging.warning(f"Decomposition of {area} timed out.")
+    #     return []
+
+    ret = Polygon.convex_decompose(Polygon.from_tuples(area.coords_zipped), [Polygon.from_tuples(hole) for hole in area.holes])
 
-    except FunctionTimedOut:
-        logging.warning(f"Decomposition of {area} timed out.")
-        return []
     convex_polygons = [[p.as_tuple() for p in polyg.points] for polyg in ret]
     ret = paths_to_areas(convex_polygons, area)
 
